#!/bin/bash


# initializing some variables
backup_date=`date | awk '{ print $3"."$2"."$6 }'`
host=`hostname`

[ ! -d /mnt/nfs ] && mkdir -p /mnt/nfs

# set the backup directory
if [ "$host" = "gate" ] ; then
	mount -tnfs hackstation:/mnt/lfs/backup /mnt/nfs
	backup_dir="/mnt/nfs"
elif [ "$host" = "sparc" ] ; then
	mount -tnfs hackstation:/mnt/lfs/backup /mnt/nfs
	backup_dir="/mnt/nfs"
elif [ "$host" = "mobile" ] ; then
        mount -tnfs hackstation:/mnt/lfs/backup /mnt/nfs
        backup_dir="/mnt/nfs"
elif [ "$host" = "right-hand" ] ; then
	mount -tnfs hackstation:/mnt/lfs/backup /mnt/nfs
	backup_dir="/mnt/nfs"
elif [ "$host" = "hackstation" ] ; then 
	backup_dir="/mnt/lfs/backup"
elif [ "$host" = "hdw" ] ; then
	mount -tnfs hackstation:/mnt/lfs/backup /mnt/nfs
	backup_dir="/mnt/nfs"
elif [ "$host" = "compaq" ] ; then
	mount -tnfs hackstation:/mnt/lfs/backup /mnt/nfs
	backup_dir="/mnt/nfs"
else
	echo "pls adept the script for $host ..."
	exit 1
fi

if [ ! -z "$2" ] ; then
if [ "$2" = "-backup_dir" -a -d $3 ] ; then
	echo "using $3 as a backup directory ..."
	backup_dir=$3
fi
fi

# set kernel version(s) to store their .config
if [ -d /usr/src/linux ] ; then
	kernel_num=`ls /usr/src/ | grep '^linux-' | sed 's/linux-//g'`
fi


# which method to use?
if [ "$1" = "tar" ] ; then
	method="tar"
elif [ "$1" = "dir" ] ; then 
	method="dir"
elif [ -z "$1" ] ; then
	method="tar"
else
	echo "aborting!"
	echo "usage: $0 [tar|dir] (-backup_dir /foo/bar)"
	echo 
	echo "tar: creates an archive called backup_${backup_date}.tar.bz2"
	echo "dir: creates just the directory backup_${backup_date}"
	exit 0
fi


# creating backup
if [ -d ${backup_dir}/${host}-backup-${backup_date} ] ; then
	echo "u already did a backup today! remove it manually first!"
	[ ! "$host" = "hackstation" ] && umount /mnt/nfs
	exit 0
fi

mkdir $backup_dir/${host}-backup-${backup_date} && cd ${backup_dir}/${host}-backup-${backup_date}


#config stuff
echo "config stuff:"
mkdir ./${host}-conf && cd ./${host}-conf 

for i in $kernel_num; do
	if [ -f /usr/src/linux-${i}/.config ] ; then
		echo "copying /usr/src/linux/.config"
		cp /usr/src/linux-${i}/.config ./$host-kernel-${i}-config
	fi
done

mkdir ./etc
for i in init.d conf opt ppp cups; do
	if [ -d /etc/$i ] ; then
		echo "copying /etc/$i"
		cp -r /etc/$i ./etc
	fi
done

for i in dhcpd.conf fstab hosts host.conf hosts.allow hosts.deny lilo.conf \
		profile sendmail.cf resolv.conf exports fb.modes inetd.conf \
		xinetd.conf mp3user mp3db.conf modules.conf named.conf \
		modprobe.devfs modprobe.conf devfsd.conf ; do
	if [ -f /etc/$i ] ; then
	echo "copying /etc/$i"
	cp /etc/$i ./etc
	fi
done

if [ -f /etc/X11/XF86Config ] ; then
	mkdir -p ./etc/X11
	echo "copying /etc/X11/XF86Config*"
	cp /etc/X11/XF86Config* ./etc/X11
fi


# specific config stuff

# gate specific config stuff!
if [ "$host" = "gate" ] ; then
	
	# mail config stuff
	if [ -d /etc/mail ] ; then
		echo "copying /etc/mail directory"
		cp -r /etc/mail ./etc
	fi

	# mlsit procmail
	if [ -d /home/mlist ] ; then
		echo "copying mlist procmail config"
		cp -r /home/mlist mlsit_pm_config
	fi

	# irc stuff 
	mkdir -p ./ircd
	[ -f /etc/opt/unrealircd/unrealircd.conf ] && \
		cp /etc/opt/unrealircd/unrealircd.conf ./ircd
fi

# right-hand specific config stuff
if [ "$host" = "right-hand" ] ; then
        if [ -d /var/named ] ; then
		mkdir ./named
                echo "copying dns data"
                cp -r /var/named/* ./named
        fi
fi


# data stuff
echo "data stuff:"

# data backup (specific)
cd ${backup_dir}/${host}-backup-${backup_date}

# gate specific data 
if [ "$host" = "gate" ] ; then
	
	# mail stuff
	for i in `ls -A /var/mail`; do
		mkdir -p mail_$i
		echo "copying mail stuff"
		cp /var/mail/$i ./mail_$i
	done
fi

# right-hand data
if [ "$host" = "right-hand" ] ; then
	mkdir ./chroot
	for i in www cvs hdw; do
		if [ -d /chroot/$i ] ; then
			echo "copying /chroot/$i"
			tar -cf ./chroot/$i.tar /chroot/$i
		fi
	done
fi

# hackstation / mobile / hdw / sparc specific data
if [ "$host" = "hackstation" -o "$host" = "mobile" -o "$host" = "hdw" -o "$host" = "sparc" -o "$host" = "compaq" ] ; then

	# home of hackbard
	mkdir -p ./home/hackbard
	echo "copying home"
	for i in temp test; do
		[ -d /home/hackbard/$i ] && \
			cp -r /home/hackbard/$i ./home/hackbard
	done
	for i in xinitrc_evil xinitrc_wm .xinitrc GNUstep .Xauthority \
			.Xdefaults .XHkeys .signature .directfbrc .bashrc ; do
		[ -e /home/hackbard/$i ] && \
			cp -r /home/hackbard/$i ./home/hackbard
	done
        if [ -d /home/hackbard/.mozilla ] &&
		cp /home/hackbard/.mozilla/default/*/bookmarks.html \
			mozilla-bookmarks.html
	[ -d /home/hackbard/.ssh ] && cp -r /home/hackbard/.ssh ./home/hackbard
	
	# tftpboot
	if [ -d /tftpboot ] ; then
		mkdir -p ./tftpboot
		echo "copying tftpboot stuff"
		cp -r /tftpboot/* ./tftpboot
	fi

	# wlan configs
	for i in hunz_prism hunz_lucent roman_orinoco.sh; do
		if [ -f /root/${i}.sh ]; then
			mkdir -p ./root
			cp /root/${i}.sh ./root
		fi
	done

fi


# data stuff (none specific)

# backing up myself
cp -r $HOME/scripts ./


# finished copying stuff, entering last backup procedure now :)))

cd $backup_dir

if [ "$method" = "tar" ] ; then
	echo "creating tar"
	tar cf ./${host}-backup-${backup_date}.tar \
				./${host}-backup-${backup_date}
	rm -r ./${host}-backup-${backup_date}
	bzip2 ./${host}-backup-${backup_date}.tar
fi


# end! umounting nfs shared backup directory
if [ "$host" != "hackstation" ] ; then
	echo "umounting nfs backup - dir"
	cd $HOME && umount /mnt/nfs
fi

echo "done ..."
